@@ -136,23 +136,27 @@ def upload_artifact(run_id: int, artifact: Artifact, artifact_digest: str, teamN
             metadata=json.dumps(artifact.meta_data),
             teamName=teamName,
             expName=expName,
-            entry_list=entry_list,
+            artifact_entry=entry_list,
         ),
         authorization=http_interface.get_jwt_key(),
     ))
     return rsp.artifact_id if rsp.rsp_result.result == "success" else None
 
 def use_artifact(name: str, type: str, tag: str, team_name: str, exp_name: str, run_id: int) -> Tuple(int, ArtifactRecord):
-    rsp: UseArtifactResponse = get_stub().use_artifact(UseArtifactRequest(
-        artifact_name=name,
-        artifact_type=type,
-        artifact_tag=tag,
-        team_name=team_name,
-        exp_name=exp_name,
-        run_id=run_id,
-        authorization=http_interface.get_jwt_key(),
-    ))
-    return rsp.artifact_id, rsp.artifact
+    try:
+        rsp: UseArtifactResponse = get_stub().use_artifact(UseArtifactRequest(
+            artifact_name=name,
+            artifact_type=type,
+            artifact_tag=tag,
+            team_name=team_name,
+            exp_name=exp_name,
+            run_id=run_id,
+            authorization=http_interface.get_jwt_key(),
+        ))
+    except grpc.RpcError as e:
+        print(e)
+        return "fail" ,"network error" , -1  ,None
+    return rsp.rsp_result.result , rsp.rsp_result.message, rsp.artifact_id, rsp.artifact
 
 def download_artifact():
     pass
